@@ -1,15 +1,13 @@
 --- Each SDK may have different environment variable configurations.
 --- This allows plugins to define custom environment variables (including PATH settings)
 --- Note: Be sure to distinguish between environment variable settings for different platforms!
---- @param ctx table Context information
---- @field ctx.path string SDK installation directory
+--- @param ctx {path: string}  Context information (SDK installation directory)
 function PLUGIN:EnvKeys(ctx)
     local mainPath = ctx.path
     return {
         {
             key = "PATH",
-            value = mainPath
-        }
+            value = mainPath,
+        },
     }
-
-end
\ No newline at end of file
+end
