@@ -8,7 +8,7 @@ use crate::build_time::built_info;
 use crate::cli::self_update::SelfUpdate;
 use crate::cli::version;
 use crate::cli::version::VERSION;
-use crate::config::{Config, IGNORED_CONFIG_FILES};
+use crate::config::{Config, IGNORED_CONFIG_FILES, Settings};
 use crate::env::PATH_KEY;
 use crate::file::display_path;
 use crate::git::Git;
@@ -72,7 +72,9 @@ impl Doctor {
             "self_update_available".into(),
             SelfUpdate::is_available().into(),
         );
-        if env::is_activated() && shims_on_path() {
+        // Warn about shims+activate conflict, but not when not_found_auto_install is enabled
+        // since that intentionally preserves shims for auto-install functionality
+        if env::is_activated() && shims_on_path() && !Settings::get().not_found_auto_install {
             self.errors.push("shims are on PATH and mise is also activated. You should only use one of these methods.".to_string());
         }
         data.insert(
@@ -196,7 +198,9 @@ impl Doctor {
         {
             info::section("self_update_instructions", instructions)?;
         }
-        if env::is_activated() && shims_on_path() {
+        // Warn about shims+activate conflict, but not when not_found_auto_install is enabled
+        // since that intentionally preserves shims for auto-install functionality
+        if env::is_activated() && shims_on_path() && !Settings::get().not_found_auto_install {
             self.errors.push("shims are on PATH and mise is also activated. You should only use one of these methods.".to_string());
         }
 
