@@ -12,7 +12,7 @@ use crate::toolset::{
 };
 use crate::ui::multi_progress_report::MultiProgressReport;
 use crate::ui::progress_report::SingleReport;
-use crate::{config, ui};
+use crate::{config, exit, runtime_symlinks, ui};
 use console::Term;
 use demand::DemandOption;
 use eyre::{Context, Result, eyre};
@@ -72,6 +72,12 @@ pub struct Upgrade {
     #[clap(long, verbatim_doc_comment)]
     before: Option<String>,
 
+    /// Like --dry-run but exits with code 1 if there are outdated tools
+    ///
+    /// This is useful for scripts to check if tools need to be upgraded.
+    #[clap(long, verbatim_doc_comment)]
+    dry_run_code: bool,
+
     /// Directly pipe stdin/stdout/stderr from plugin to user
     /// Sets --jobs=1
     #[clap(long, overrides_with = "jobs")]
@@ -79,6 +85,10 @@ pub struct Upgrade {
 }
 
 impl Upgrade {
+    fn is_dry_run(&self) -> bool {
+        self.dry_run || self.dry_run_code
+    }
+
     pub async fn run(self) -> Result<()> {
         let mut config = Config::get().await?;
         let ts = ToolsetBuilder::new()
@@ -177,7 +187,7 @@ impl Upgrade {
             })
             .collect();
 
-        if self.dry_run {
+        if self.is_dry_run() {
             for (o, current) in &to_remove {
                 miseprintln!("Would uninstall {}@{}", o.name, current);
             }
@@ -192,6 +202,9 @@ impl Upgrade {
                     display_path(cf.get_path())
                 );
             }
+            if self.dry_run_code {
+                exit::exit(1);
+            }
             return Ok(());
         }
 
@@ -246,6 +259,12 @@ impl Upgrade {
         // Reset config after upgrades so tracked configs resolve with new versions
         *config = Config::reset().await?;
 
+        // Rebuild symlinks BEFORE getting versions needed by tracked configs
+        // This ensures "latest" symlinks point to the new versions, not the old ones
+        runtime_symlinks::rebuild(config)
+            .await
+            .wrap_err("failed to rebuild runtime symlinks")?;
+
         // Get versions needed by tracked configs AFTER upgrade
         // This ensures we don't uninstall versions still needed by other projects
         let versions_needed_by_tracked = get_versions_needed_by_tracked_configs(config).await?;
