@@ -28,6 +28,7 @@ use crate::file::display_path;
 use crate::shorthands::{Shorthands, get_shorthands};
 use crate::task::task_file_providers::TaskFileProvidersBuilder;
 use crate::task::{Task, TaskTemplate};
+use crate::tera::take_tera_accessed_files;
 use crate::toolset::env_cache::{CachedNonToolEnv, compute_settings_hash, get_file_mtime};
 use crate::toolset::{
     ToolRequestSet, ToolRequestSetBuilder, ToolVersion, ToolVersionOptions, Toolset, install_state,
@@ -63,6 +64,9 @@ pub struct Config {
     pub tera_ctx: tera::Context,
     pub shorthands: Shorthands,
     pub shell_aliases: EnvWithSources,
+    /// Files accessed by tera template functions (read_file, hash_file, etc.)
+    /// during shell alias template rendering, used to watch for changes in hook-env.
+    pub tera_files: Vec<PathBuf>,
     aliases: AliasMap,
     env: OnceCell<EnvResults>,
     env_with_sources: OnceCell<EnvWithSources>,
@@ -150,6 +154,7 @@ impl Config {
             project_root: Default::default(),
             repo_urls: Default::default(),
             shell_aliases: Default::default(),
+            tera_files: Default::default(),
             vars: Default::default(),
             vars_loader: None,
             vars_results: OnceCell::new(),
@@ -169,6 +174,7 @@ impl Config {
             project_root: config.project_root.clone(),
             repo_urls: config.repo_urls.clone(),
             shell_aliases: config.shell_aliases.clone(),
+            tera_files: config.tera_files.clone(),
             vars: config.vars.clone(),
             vars_loader: None,
             vars_results: OnceCell::new(),
@@ -189,7 +195,10 @@ impl Config {
 
         config.vars = vars;
         config.aliases = load_aliases(&config.config_files)?;
+        // Clear any previously tracked files before loading shell aliases
+        let _ = take_tera_accessed_files();
         config.shell_aliases = load_shell_aliases(&config.config_files)?;
+        config.tera_files = take_tera_accessed_files();
         config.project_root = get_project_root(&config.config_files);
         config.repo_urls = load_plugins(&config.config_files)?;
         measure!("config::load validate", {
@@ -341,7 +350,17 @@ impl Config {
         backend_arg: &Arc<BackendArg>,
     ) -> Result<Option<ToolVersionOptions>> {
         let trs = self.get_tool_request_set().await?;
-        let tool_request = trs.iter().find(|tr| tr.0.short == backend_arg.short);
+        // Try matching by resolved full name first for aliased tools.
+        // e.g., ba.short="treesize" resolves to full="gitlab:FBibonne/treesize"
+        // while the config entry has short="gitlab-f-bibonne-treesize" with api_url set.
+        // We check the resolved name first because the direct short match might find
+        // a CLI-created tool request without options.
+        let full = backend_arg.full();
+        let resolved_ba = BackendArg::new(full, None);
+        let tool_request = trs
+            .iter()
+            .find(|tr| tr.0.short == resolved_ba.short)
+            .or_else(|| trs.iter().find(|tr| tr.0.short == backend_arg.short));
         Ok(tool_request.and_then(|tr| tr.1.first().map(|req| req.options())))
     }
 
@@ -712,8 +731,17 @@ impl Config {
             .get_or_try_init(|| async {
                 self.config_files
                     .values()
-                    .map(|cf| Ok((cf.project_root(), cf.hooks()?)))
-                    .filter_map_ok(|(root, hooks)| root.map(|r| (r.to_path_buf(), hooks)))
+                    .map(|cf| {
+                        let is_global = cf.project_root().is_none();
+                        let root = cf.project_root().unwrap_or_else(|| cf.config_root());
+                        let mut hooks = cf.hooks()?;
+                        if is_global {
+                            for h in &mut hooks {
+                                h.global = true;
+                            }
+                        }
+                        Ok((root, hooks))
+                    })
                     .map_ok(|(root, hooks)| {
                         hooks
                             .into_iter()
@@ -770,6 +798,7 @@ impl Config {
                     .iter()
                     .map(|p| p.as_path().into()),
             )
+            .chain(self.tera_files.iter().map(|p| p.as_path().into()))
             .collect())
     }
 
