@@ -139,9 +139,10 @@ impl Backend for ElixirPlugin {
         ctx: &InstallContext,
         mut tv: ToolVersion,
     ) -> Result<ToolVersion> {
-        ctx.pr.start_operations(3);
         let tarball_path = self.download(&tv, ctx.pr.as_ref()).await?;
+        ctx.pr.next_operation();
         self.verify_checksum(ctx, &mut tv, &tarball_path)?;
+        ctx.pr.next_operation();
         self.install(ctx, &tv, &tarball_path).await?;
         self.verify(ctx, &tv).await?;
         Ok(tv)
