@@ -488,10 +488,20 @@ impl Backend for NodePlugin {
     }
 
     async fn idiomatic_filenames(&self) -> Result<Vec<String>> {
-        Ok(vec![".node-version".into(), ".nvmrc".into()])
+        Ok(vec![
+            ".node-version".into(),
+            ".nvmrc".into(),
+            "package.json".into(),
+        ])
     }
 
     async fn parse_idiomatic_file(&self, path: &Path) -> Result<String> {
+        if path.file_name().is_some_and(|f| f == "package.json") {
+            let pkg = crate::package_json::PackageJson::parse(path)?;
+            return pkg
+                .runtime_version("node")
+                .ok_or_else(|| eyre::eyre!("no node version found in package.json"));
+        }
         let body = file::read_to_string(path)?;
         // strip comments
         let body = body.split('#').next().unwrap_or_default().to_string();
