@@ -328,8 +328,8 @@ impl Task {
             })
             .map(|captures| captures.extract().1)
             .map(|[toml]| {
-                toml.parse::<toml::Value>()
-                    .map_err(|e| eyre::eyre!("failed to parse task header TOML '{}': {}", toml, e))
+                toml::de::from_str::<toml::Value>(toml)
+                    .map_err(|e| eyre::eyre!("failed to parse task header TOML {toml:?}: {e}"))
             })
             .collect::<Result<Vec<_>>>()?
             .into_iter()
