@@ -1,4 +1,3 @@
-use crate::cli::version::V;
 use crate::config::{Config, Settings};
 use crate::env_diff::EnvMap;
 use crate::exit::exit;
@@ -12,7 +11,6 @@ use std::collections::{HashMap, HashSet};
 use std::iter::once;
 use std::path::PathBuf;
 use std::sync::{Arc, Mutex};
-use versions::Versioning;
 
 type TeraSpecParsingResult = (
     tera::Tera,
@@ -62,27 +60,14 @@ impl TaskScriptParser {
             return;
         }
 
-        // Debug assertion to ensure we remove this functionality after 2026.11.0
-        let removal_version = Versioning::new("2026.11.0").unwrap();
-        debug_assert!(
-            *V < removal_version,
-            "Tera template task arguments (arg/option/flag functions) should have been removed in version 2026.11.0. \
-             Please remove this deprecated functionality from task_script_parser.rs"
+        deprecated_at!(
+            "2026.5.0",
+            "2027.5.0",
+            "tera_template_task_args",
+            "Task '{}' uses deprecated Tera template functions (arg(), option(), flag()) in run scripts. \
+             Use the 'usage' field instead. See https://mise.jdx.dev/tasks/task-arguments.html",
+            task_name
         );
-
-        // Show deprecation warning for versions >= 2026.5.0
-        let deprecation_version = Versioning::new("2026.5.0").unwrap();
-        if *V >= deprecation_version {
-            deprecated!(
-                "tera_template_task_args",
-                "Task '{}' uses deprecated Tera template functions (arg(), option(), flag()) in run scripts. \
-                 This will be removed in mise 2026.11.0. The template functions require two-pass parsing which \
-                 causes unexpected behavior - they return empty strings during spec collection and have complex \
-                 escaping rules. The 'usage' field is cleaner, works consistently between TOML/file tasks, and \
-                 provides all the same functionality. See migration guide: https://mise.jdx.dev/tasks/task-arguments/#tera-templates",
-                task_name
-            );
-        }
     }
 
     // Helper functions for tera error handling
