@@ -76,11 +76,12 @@ impl ToolVersionOptions {
 
         // Get the root value and try to parse it as TOML
         if let Some(value) = self.opts.get(root_key) {
-            if let Ok(toml_value) = value.parse::<toml::Value>() {
+            if let Ok(toml_value) = toml::de::from_str::<toml::Value>(value) {
                 return Self::value_exists_at_path(&toml_value, nested_path);
             } else if value.trim().starts_with('{') && value.trim().ends_with('}') {
                 // Try to parse as inline TOML table
-                if let Ok(toml_value) = format!("value = {value}").parse::<toml::Value>()
+                if let Ok(toml_value) =
+                    toml::de::from_str::<toml::Value>(&format!("value = {value}"))
                     && let Some(table_value) = toml_value.get("value")
                 {
                     return Self::value_exists_at_path(table_value, nested_path);
@@ -121,11 +122,12 @@ impl ToolVersionOptions {
 
         // Get the root value and try to parse it as TOML
         if let Some(value) = self.opts.get(root_key) {
-            if let Ok(toml_value) = value.parse::<toml::Value>() {
+            if let Ok(toml_value) = toml::de::from_str::<toml::Value>(value) {
                 return Self::get_string_at_path(&toml_value, nested_path);
             } else if value.trim().starts_with('{') && value.trim().ends_with('}') {
                 // Try to parse as inline TOML table
-                if let Ok(toml_value) = format!("value = {value}").parse::<toml::Value>()
+                if let Ok(toml_value) =
+                    toml::de::from_str::<toml::Value>(&format!("value = {value}"))
                     && let Some(table_value) = toml_value.get("value")
                 {
                     return Self::get_string_at_path(table_value, nested_path);
