@@ -22,6 +22,26 @@ impl Toolset {
         Ok(env)
     }
 
+    /// Like full_env but skips `tools=true` env directives (load_post_env).
+    /// Used for preinstall hooks where tool-dependent env vars aren't available yet.
+    pub async fn full_env_without_tools(&self, config: &Arc<Config>) -> Result<EnvMap> {
+        let mut env = env::PRISTINE_ENV.clone().into_iter().collect::<EnvMap>();
+        let (tool_env, add_paths) = self.env(config).await?;
+        env.extend(tool_env);
+        let mut path_env = PathEnv::from_iter(env::PATH.clone());
+        for p in config.path_dirs().await?.clone() {
+            path_env.add(p);
+        }
+        for p in &add_paths {
+            path_env.add(p.clone());
+        }
+        for p in self.list_paths(config).await {
+            path_env.add(p);
+        }
+        env.insert(PATH_KEY.to_string(), path_env.to_string());
+        Ok(env)
+    }
+
     /// the full mise environment including all tool paths
     pub async fn env_with_path(&self, config: &Arc<Config>) -> Result<EnvMap> {
         // Try to load from cache if enabled
@@ -247,7 +267,7 @@ impl Toolset {
             .collect()
     }
 
-    pub(super) async fn env(&self, config: &Arc<Config>) -> Result<(EnvMap, Vec<PathBuf>)> {
+    pub async fn env(&self, config: &Arc<Config>) -> Result<(EnvMap, Vec<PathBuf>)> {
         time!("env start");
         let entries = self
             .env_from_tools(config)
@@ -300,6 +320,7 @@ impl Toolset {
         tera_env.insert(PATH_KEY.to_string(), path_env.to_string());
         let mut ctx = config.tera_ctx.clone();
         ctx.insert("env", &tera_env);
+        ctx.insert("tools", &self.build_tools_tera_map(config));
         let mut env_results = self.load_post_env(config, ctx, &tera_env).await?;
 
         // Store add_paths separately to maintain consistent PATH ordering
